import request from '@/utils/request'

// 查询报送数据项配置列表
export function listGIVE(query) {
  return request({
    url: '/norm/GIVE/list',
    method: 'get',
    params: query
  })
}

// 查询报送数据项配置所有列表
export function listAllGIVE(query) {
  return request({
    url: '/norm/GIVE/listAll',
    method: 'get',
    params: query
  })
}

// 查询报送数据项配置详细
export function getGIVE(id) {
  return request({
    url: '/norm/GIVE/getInfo/' + id,
    method: 'get'
  })
}

// 新增报送数据项配置
export function addGIVE(data) {
  return request({
    url: '/norm/GIVE/add',
    method: 'post',
    data: data
  })
}

// 修改报送数据项配置
export function updateGIVE(data) {
  return request({
    url: '/norm/GIVE/edit',
    method: 'post',
    data: data
  })
}

// 删除报送数据项配置
export function delGIVE(id) {
  return request({
    url: '/norm/GIVE/remove/' + id,
    method: 'get'
  })
}
